#
# spec file for package google-guest-configs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550 && 0%{?sle_version} < 150300
%define _udevdir %(pkg-config --variable udevdir udev)
%define _modprobedir %{_sysconfdir}/modprobe.d
%else
%define _udevdir %(pkg-config --variable udev_dir udev)
%endif
Name:           google-guest-configs
Version:        20250516.00
Release:        2.1
Summary:        Google Cloud Guest Configs
License:        Apache-2.0
Group:          System/Daemons
URL:            https://github.com/GoogleCloudPlatform/guest-configs
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
# FIXME (https://github.com/GoogleCloudPlatform/guest-configs/pull/96)
Patch1:         ggc-no-dup-metasrv-entry.patch
BuildRequires:  sysconfig
BuildRequires:  sysconfig-netconfig
BuildRequires:  systemd-rpm-macros
%if 0%{?suse_version} && 0%{?suse_version} <= 1315
BuildRequires:  pkg-config
%endif
BuildRequires:  pkgconfig(udev)
Requires:       nvme-cli
BuildArch:      noarch

%description
Google Cloud Guest Configs

%prep
%setup -q -n guest-configs-%{version}
%patch -P 1

%build
# Nothing to build

%install
mkdir -p %{buildroot}%{_modprobedir}
cp -av src/etc/modprobe.d/* %{buildroot}%{_modprobedir}
mkdir -p %{buildroot}%{_sysconfdir}/rsyslog.d
cp -av src/etc/rsyslog.d/* %{buildroot}%{_sysconfdir}/rsyslog.d/
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/network/scripts
cp -av src/etc/sysconfig/network/scripts/google_up.sh %{buildroot}%{_sysconfdir}/sysconfig/network/scripts/
mkdir -p %{buildroot}%{_sysctldir}
cp -av src/etc/sysctl.d/* %{buildroot}%{_sysctldir}
mkdir -p %{buildroot}%{_udevrulesdir}
cp -av src/lib/udev/rules.d/* %{buildroot}%{_udevrulesdir}/
cp -av src/lib/udev/google_nvme_id %{buildroot}/%{_udevdir}/
mkdir -p %{buildroot}%{_bindir}
cp -av src/usr/bin/* %{buildroot}%{_bindir}/

%post
if [ -f %{_sysconfdir}/sysconfig/network/ifcfg-eth0 ] && \
    ! grep 'POST_UP_SCRIPT="compat:suse:google_up.sh"' %{_sysconfdir}/sysconfig/network/ifcfg-eth0 >/dev/null ; then
    echo 'POST_UP_SCRIPT="compat:suse:google_up.sh"' >> %{_sysconfdir}/sysconfig/network/ifcfg-eth0
fi

%postun
if [ -f %{_sysconfdir}/sysconfig/network/ifcfg-eth0 ] ; then
    sed -i '/POST_UP_SCRIPT="compat:suse:google_up.sh"/d' %{_sysconfdir}/sysconfig/network/ifcfg-eth0
fi

%files
%defattr(0644,root,root,0755)
%doc README.md
%license LICENSE
%attr(0755,root,root) %{_bindir}/google_optimize_local_ssd
%attr(0755,root,root) %{_bindir}/google_set_hostname
%attr(0755,root,root) %{_bindir}/google_set_multiqueue
%if 0%{?suse_version} < 1550 && 0%{?sle_version} < 150300
%dir %{_modprobedir}
%endif
%attr(0755, root, root) %{_bindir}/gce-nic-naming
%dir %{_sysconfdir}/rsyslog.d
%{_modprobedir}/gce-blacklist.conf
%config %{_sysconfdir}/rsyslog.d/*
%config %{_sysconfdir}/sysconfig/network/scripts/*
%{_sysctldir}/*
%attr(0755,root,root) %{_udevdir}/google_nvme_id
%{_udevrulesdir}/*

%changelog
* Tue Jun  3 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Check that %%{_sysconfdir}/sysconfig/network/ifcfg-eth0 actually
  exists before making any modifications to it (bsc#1241112)
* Mon May 26 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20250516.00
  * Merge pull request #109 from xiliuxyz:master
  * Remove unused fset
  * Remove unused lines
  * Update google_set_multiqueue to unpack IRQ ranges before core assignment
* Wed May 14 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20250501.00
  * Configure local domain as route only domain to support cloud dns local
    domain but avoid adding it to the search path.
- from version 20250409.00
  * Change RDMA test condition to ensure renaming race conditions can be
    detected. If such a case is detected the script will err and exit rather
    than returning a name. Udev accepts this and continues as though the rule
    was not triggered in such a case.
- from version 20250328.00
  * Merge pull request #105 from dorileo:revert-ubuntu-hostname-hooks
  * Revert "Include systemd-networkd hook in Ubuntu packaging (#77)"
- from version 20250326.00
  * Merge pull request #104 from xiliuxyz:master
  * Merge pull request #1 from xiliuxyz/xiliuxyz-patch-1
  * Update google_set_multiqueue to check pnic_ids
- from version 20250221.00
  * Merge pull request #103 from a-r-n:master
  * Make google_set_multiqueue aware A4X is multinic_accelerator_platform
- from version 20250207.00
  * Merge pull request #102 from xiliuxyz:master
  * Update google_set_multiqueue to adapt A4 platform
  * Merge branch 'GoogleCloudPlatform:master' into master
  * Fix IS_A3_PLATFORM syntax
  * Fix IS_A3_PLATFORM syntax
  * Correct IS_A3_PLATFORM to save is_a3_platform results
  * Remove excess empty line.
  * Store is_a3_platform results into a global variable to avoid redundant curl calls
  * Skip tx affinity binding on non-gvnic interfaces only on A3 platforms.
  * Skip tx affinity binding on non-gvnic interfaces
  * Update comments for get_vcpu_ranges_on_accelerator_platform
    to reflect the expected vcpu ranges
  * rename get_vcpu_ranges to get_vcpu_ranges_on_accelerator_platform
  * Avoid IRQ binding on vCPU 0
  * Fix returned value for get_vcpu_ranges
  * Update get_vcpu_ranges to read from sys file instead of hardcoded value
  * Update google_set_multiqueue
  * Update google_set_multiqueue to set vCPU ranges based on platform
  * Merge branch 'GoogleCloudPlatform:master' into master
  * Add comment for handling IRQ binding on non-gvnic devices
  * Remove excess empty line.
  * Update is_gvnic to include gvnic driver checks
  * Merge branch 'master' into master
  * revert removed echo lines
  * Update google_set_multiqueue to skip set_irq if nic is not a gvnic device.
  * Update google_set_multiqueue to enable on A3Ultra family
- from version 20250124.00
  * Merge pull request #88 from zmarano:nvme
  * Fix missing files. This is a no-op.
  * No public description
  * Also force virtio_scsi.
- from version 20250116.00
  * Add GPL-2 to licensing information (#98)
- from version 20250107.00
  * Restore IDPF devices for renaming rules (#95)
- from version 20241213.00
  * Remove Pat from owners file. (#97)
* Mon Dec 30 2024 Robert Schweikert <rjschwei@suse.com>
- Add ggc-no-dup-metasrv-entry.patch
  + Follow up to (bsc#1234289, bsc#1234293). Avoid duplicate entries for
    the metadata server in /etc/hosts
* Thu Dec 12 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20241205.00 (bsc#1234254, bsc#1234255)
  * Update google_set_multiqueue to configure
    vCPU ranges based on VM platform (#90)
- from version 20241204.00
  * Restore google_set_multiqueue changes for A3Ultra (#93)
  * Depend on networkd-dispatcher in Ubuntu (#94)
- Include components to set hostname and /etc/hosts entries (bsc#1234289, bsc#1234293)
  * Add sysconfig and sysconfig-network to BuildRequires
  * Install google_set_hostname into %%{_bindir}
  * Install google_up.sh into %%{_sysconfdir}/sysconfig/network/scripts/
  * Add code to add and remove POST_UP_SCRIPT="compat:suse:google_up.sh"
    to /etc/sysconfig/network/ifcfg-eth0 in %%post and %%postun sections
* Tue Dec  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20241121.00 (bsc#1233625, bsc#1233626)
  * Temporarily revert google_set_multiqueue changes for release (#92)
- from version 20241115.00
  * Remove IDPF devices from renaming rules (#91)
- from version 20241112.00
  * Revert "Revert 3 commits:" (#89)
- from version 20241108.00
  * Revert 3 commits: (#87)
- from version 20241107.00
  * gce-nic-naming: Exit 1 so that udev ignores the rule on error (#86)
- from version 20241106.00
  * Remove Apt IPv4 only config for Debian and Ubuntu (#85)
- from version 20241031.00
  * Add GCE intent based NIC naming tools (#84)
- from version 20241025.00
  * Update google_set_multiqueue to skip set_irq
    if NIC is not a gvnic device (#83)
- Add new binary gce-nic-naming to %%{_bindir} in %%files section
* Tue Oct 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20241021.00 (bsc#1231775, bsc#1231776)
  * Add GCE-specific config for systemd-resolved (#82)
- from version 20241015.00
  * Update google_set_multiqueue to enable on A3Ultra family (#79)
- from version 20241013.00
  * Update OWNERS (#81)
- from version 20241010.00
  * Depend on jq in enterprise linux (#80)
- from version 20241008.00
  * Always use IP from primary NIC in the
    networkd-dispatcher routable hook (#78)
* Mon Sep 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240925.00
  * Call google_set_hostname on openSUSE and when the agent
    is configured to manage hostname and FQDN, let it (#75)
- from version 20240924.00
  * Include systemd-networkd hook in Ubuntu packaging (#77)
- from version 20240905.00
  * Update packaging as of Ubuntu devel packaging (#65)
- from version 20240830.00
  * Fix the name for A3 Edge VMs (#76)
* Mon Aug  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240725.00
  * Fix: hostnamectl command (#74)
* Fri Jun 14 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240607.00
  * Update is_a3_platform to include A3-edge shape (#73)
* Thu May 16 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240514.00
  * Add systemd-networkd hostname hook (#71)
- from version 20240501.00
  * Add hostname hook for NetworkManager without
    dhclient compat script (#70)
* Fri Mar 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240307.00 (bsc#1221146, bsc#1221900, bsc#1221901)
  * Support dot in NVMe device ids (#68)
- from version 20240304.00
  * google_set_hostname: Extract rsyslog service name
    with a regexp for valid systemd unit names (#67)
- from version 20240228.00
  * Remove quintonamore from OWNERS (#64)
- from version 20240119.00
  * Setup smp affinity for IRQs and XPS on A3+ VMs (#63)
* Thu Jan  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20231214.00
  * set multiqueue: A3 check set timeout the MDS call in 1s (#62)
- from version 20231103.00
  * Update owners (#61)
  * Update owners (#58)
* Thu Oct 19 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230929.00
  * Update multinic filter to pick only pci devices (#59)
* Tue Aug 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230808.00 (bsc#1214546, bsc#1214572)
  * 64-gce-disk-removal.rules: delete (#51)
- from version 20230801.00
  * Replace xxd with dd for google_nvme_id (#56)
- from version 20230729.00
  * Setup irq binding for a3 8g vm (#57)
- from version 20230724.00
  * Debian packaging: add xxd dependency (#55)
* Tue Jun 27 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230626.00 (bsc#1212418, bsc#1212759)
  * Revert "Replace `xxd` to `cut` for google_nvme_id (#49)" (#54)
* Thu Jun  8 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230526.00
  * dracut: Add a new dracut module for gcp udev rules (#53)
- from version 20230522.00
  * src/lib/udev: only create symlinks for GCP devices (#52)
- from version 20230515.00
  * Replace `xxd` to `cut` for google_nvme_id (#49)
- from version 20230328.00
  * Set hostname: consider fully qualified static hostname (#46)
* Mon Feb 27 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230217.01
  * Support multiple local SSD controllers (#39)
- from version 20230217.00
  * Update OWNERS (#45)
- from version 20230215.00
  * DHCP hostname: don't reset hostname if
    the hostname hasn't changed (#44)
- from version 20230202.00
  * Update OWNERS file (#43)
- from version 20230123.00
  * Fix a repository URL in packaging specs (#41)
* Tue Oct 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add nvme-cli to Requires (bsc#1204068, bsc#1204091)
* Mon Feb 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20220211.00 (bsc#1195437, bsc#1195438)
  * Set NVMe-PD IO timeout to 4294967295. (#32)
* Fri Dec 17 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add missing pkg-config dependency to BuildRequires for SLE-12
* Tue Dec  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Install modprobe configuration files into /etc again on SLE-15-SP2 and
  older since that's stil the default location on these distributions
- Probe udev directory using the "udevdir" pkg-config variable on SLE-15-SP2
  and older since the variable got renamed to "udev_dir" in later versions
- Remove redundant pkgconfig(udev) from BuildRequires for SLE-12
* Thu Nov 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20211116.00 (bsc#1193257, bsc#1193258)
  * GCE supports up to 24 NVMe local SSDs, but the regex in the PROGRAM field
    only looks for the last digit of the given string causing issues when there
    are >= 10 local SSDs. Changed REGEX to get the last number of the string
    instead to support the up to 24 local SSDs. (#30)
  * chmod+x google_nvme_id on EL (#31)
- Fix duplicate installation of google_optimize_local_ssd and google_set_multiqueue
- Install google_nvme_id into /usr/lib/udev (bsc#1192652, bsc#1192653)
* Fri Oct 22 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210916.00
  * Revert "dont set IP in etc/hosts; remove rsyslog (#26)" (#28)
- from version 20210831.00
  * restore rsyslog (#27)
- from version 20210830.00
  * Fix NVMe partition names (#25)
- from version 20210824.00
  * dont set IP in etc/hosts; remove rsyslog (#26)
  * update OWNERS
* Fri Aug 20 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%_modprobedir for modprobe.d files (out of /etc)
- Use %%_sysctldir for sysctl.d files (out of /etc)
* Mon Jul 19 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210702.00
  * use grep for hostname check (#23)
- from version 20210629.00
  * address set_hostname vuln (#22)
- from version 20210324.00
  * dracut.conf wants spaces around values (#19)
* Wed Mar 31 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210317.00 (bsc#1183414, bsc#1183415)
  * dracut.conf wants spaces around values (#19)
  * make the same change for debian (#18)
  * change path back for google_nvme_id (#17)
  * move google_nvme_id to /usr/bin (#16)
  * correct udev rule syntax (#15)
  * prune el6 spec (#13)
  * Updated udev rules (#11)
- Remove empty %%{_sbindir} from %%install and %%files section
* Tue Jan  5 2021 Robert Schweikert <rjschwei@suse.com>
- Remove service files (bsc#1180304)
  + google-optimize-local-ssd.service, google-set-multiqueue.service
    scripts are called from within the guest agent
* Tue Aug 25 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20200626.00 (bsc#1175740, bsc#1175741)
  * Updates the udev rules for local SSD disks. (#9)
  * Fix tx affinity logic when number of CPUs is above 32 (#6)
* Fri Jul 24 2020 Robert Schweikert <rjschwei@suse.com>
- Switch udev requires to pkgconfig to allow the build service to use
  the -mini package for build optimization
* Wed Jul 22 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build (bsc#1174304, bsc#1174306, jsc#ECO-2099, jsc#PM-1945)
  + Version 20200626.00
  + Replaces configuration from google-compute-engine-{init,oslogin} package
